diff --git a/src/main/java/org/springframework/data/gemfire/support/AnnotationBasedExpiration.java b/src/main/java/org/springframework/data/gemfire/support/AnnotationBasedExpiration.java
index f58b7d1e..a480cb25 100644
--- a/src/main/java/org/springframework/data/gemfire/support/AnnotationBasedExpiration.java
+++ b/src/main/java/org/springframework/data/gemfire/support/AnnotationBasedExpiration.java
@@ -60,18 +60,10 @@ import org.springframework.util.ObjectUtils;
* @see org.springframework.data.gemfire.support.Expiration
* @see org.springframework.data.gemfire.support.IdleTimeoutExpiration
* @see org.springframework.data.gemfire.support.TimeToLiveExpiration
-<<<<<<< HEAD
* @see org.apache.geode.cache.CustomExpiry
* @see org.apache.geode.cache.ExpirationAction
* @see org.apache.geode.cache.ExpirationAttributes
* @see org.apache.geode.cache.Region
-=======
- * @see org.apache.geode.cache.CustomExpiry
- * @see org.apache.geode.cache.ExpirationAction
- * @see org.apache.geode.cache.ExpirationAttributes
- * @see org.apache.geode.cache.Region
- * @see Annotation-based Data Expiration
->>>>>>> bfb3347... SGF-516 - Configure Expiration with annotations.
* @since 1.7.0
*/
@SuppressWarnings("unused")
diff --git a/src/test/java/org/springframework/data/gemfire/GenericRegionFactoryBeanTest.java b/src/test/java/org/springframework/data/gemfire/GenericRegionFactoryBeanTest.java
index 73f3482b..00688589 100644
--- a/src/test/java/org/springframework/data/gemfire/GenericRegionFactoryBeanTest.java
+++ b/src/test/java/org/springframework/data/gemfire/GenericRegionFactoryBeanTest.java
@@ -18,6 +18,9 @@ package org.springframework.data.gemfire;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
+import static org.springframework.data.gemfire.test.support.FileSystemUtils.FileExtensionFilter.newFileExtensionFilter;
+
+import java.io.FileFilter;
import org.apache.geode.cache.Cache;
import org.apache.geode.cache.CacheFactory;
@@ -27,18 +30,20 @@ import org.apache.geode.cache.Scope;
import org.junit.AfterClass;
import org.junit.BeforeClass;
import org.junit.Test;
+import org.springframework.data.gemfire.test.support.FileSystemUtils;
+import org.springframework.data.gemfire.util.CacheUtils;
/**
- * The GenericRegionFactoryBeanTest class is a test suite of test cases testing the contract and functionality
- * of the GenericRegionFactoryBean class.
+ * Unit tests for {@link GenericRegionFactoryBean}.
*
* @author John Blum
+ * @see org.junit.Test
* @see org.springframework.data.gemfire.GenericRegionFactoryBean
* @since 1.7.0
*/
public class GenericRegionFactoryBeanTest {
// as defined in the org.apache.geode.internal.cache.AbstractRegion class
private static final Scope DEFAULT_SCOPE = Scope.DISTRIBUTED_NO_ACK;
private static Region
@@ -27,18 +30,20 @@ import org.apache.geode.cache.Scope;
*/
public class GenericRegionFactoryBeanTest {
- // as defined in the org.apache.geode.internal.cache.AbstractRegion class
+ // As defined in com.gemstone.gemfire.internal.cache.AbstractRegion
private static final Scope DEFAULT_SCOPE = Scope.DISTRIBUTED_NO_ACK;
private static Region